@@ -20,10 +20,11 @@ def tox_ubuntu_install_buildreqs(MECAB):
 
     packages = [
         "python2.7-dev", "python3.5-dev", "python3.6-dev",
-        "python3.7-dev", "tox", "swig", "mecab-ipadic-utf8"
+        "python3.7-dev", "tox", "swig"
     ]
     if MECAB == "system":
         packages.append("libmecab-dev")
+        packages.append("mecab-ipadic-utf8")
 
     run("sudo", "apt-get", "-y", "install", *packages)
 
@@ -59,8 +60,7 @@ def tox_build(MECAB, TRAVIS_OS):
 
 def cibuildwheel_ubuntu_install_buildreqs():
     run("sudo", "apt-get", "-y", "update")
-    run("sudo", "apt-get", "-y", "install",
-        "mecab-ipadic-utf8", "virtualenv")
+    run("sudo", "apt-get", "-y", "install", "virtualenv")
 
 
 def cibuildwheel_ubuntu_prep_swig():
@@ -95,20 +95,13 @@ def cibuildwheel_osx_install_buildreqs():
     os.environ.pop("HOMEBREW_INSTALL_CLEANUP", None)
     os.environ["HOMEBREW_NO_INSTALL_CLEANUP"] = "yes"
 
+    # TODO: All calls to brew can probably be removed
     run("brew", "update")
     run("brew", "--version")
-    run("brew", "install", "swig", "mecab-ipadic")
+    run("brew", "install", "swig")
     run("pip3", "install", "virtualenv")
 
 
-def cibuildwheel_osx_prep_dictionary():
-    mecab_ipadic_prefix = run_output("brew", "--prefix", "mecab-ipadic")
-    dicdir = os.path.join(mecab_ipadic_prefix, "lib/mecab/dic/ipadic")
-
-    # dicdir may be a symlink, force resolution
-    run("cp", "-a", dicdir+"/.", "build/dic")
-
-
 def cibuildwheel_build(MECAB, TRAVIS_OS):
 
     if MECAB != "bundled":
@@ -125,12 +118,10 @@ def cibuildwheel_build(MECAB, TRAVIS_OS):
         mkdir_p("build")
         cibuildwheel_ubuntu_install_buildreqs()
         cibuildwheel_ubuntu_prep_swig()
-        cibuildwheel_ubuntu_prep_dictionary()
 
     elif TRAVIS_OS == "osx":
         mkdir_p("build")
         cibuildwheel_osx_install_buildreqs()
-        cibuildwheel_osx_prep_dictionary()
 
     else:
         sys.stderr.write("Operating system {!r} not yet supported by "
@@ -148,11 +139,15 @@ def cibuildwheel_build(MECAB, TRAVIS_OS):
     run("pip", "install", "cibuildwheel")
 
     # environment variables to control cibuildwheel
+    TEST_REQUIRES = "pytest"
+    if MECAB == "bundled":
+        TEST_REQUIRES += " unidic-lite"
+
     S = setenv
     S("CIBW_ENVIRONMENT", "MECAB_DICDIR=build/dic BUNDLE_LIBMECAB=true")
     S("CIBW_BEFORE_BUILD", "{project}/scripts/cibw-prepare-"+TRAVIS_OS+".py")
     S("CIBW_TEST_COMMAND", "pytest {project}/test/")
-    S("CIBW_TEST_REQUIRES", "pytest")
+    S("CIBW_TEST_REQUIRES", TEST_REQUIRES)
     S("CIBW_BUILD_VERBOSITY", "3")
 
     run("cibuildwheel", "--output-dir", "wheelhouse")
